pycocoa.screens.Frame

Package pycocoa :: Module screens :: Class Frame |
[frames] | no frames]

# Class Frame

              object --+
                       |
    internals._Objectype --+
                           |
            baseTypes._Type0 --+
                               |
                   geometry.Rect --+
                                   |
                                  Frame

A screen frame, wrapping ObjC NSRect_t.

Instance Methods
__init__(self, screen_frame=None, fraction=None, cascade=10) New, partial screen Frame. |
Inherited from `geometry.Rect`: `__str__` Inherited from `baseTypes._Type0`: `__repr__`, `type2strepr` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
Inherited from `geometry.Rect`: `bottom`, `bottomleft`, `bottomright`, `center`, `height`, `left`, `lowerleft`, `lowerright`, `origin`, `ratio`, `rect`, `rect4`, `right`, `size`, `top`, `topleft`, `topright`, `upperleft`, `upperright`, `width`, `x`, `y` Inherited from `baseTypes._Type0`: `NS`, `NSDelegate` Inherited from `internals._Objectype`: `typename` Inherited from `object`: `__class__`

Method Details

### __init__(self, screen_frame=None, fraction=None, cascade=10) (Constructor) |
New, partial screen Frame. Parameters: `screen_frame` - The screen to place the window on (`int`) or `None` for the current one. Use `screen=0` for the BuiltIn screen or `screen=1` for the first External monitor, etc. otherwise a screen, or frame (Screen, L(Frame) or Rect). `fraction` - Size of the screen (`float`). `cascade` - Shift from lower left corner (`float` or `int`). Raises: `TypeError` - Invalid screen_frame. `ValueError` - Invalid fraction value. Overrides: object.__init__